# Code of Conduct

This project follows the [Contributor Covenant v2.1](https://www.contributor-covenant.org/version/2/1/code_of_conduct/).

## Our Pledge

We are committed to making participation in this project a welcoming experience for everyone, regardless of background or identity.

## Standards

**Positive behavior includes:** using welcoming language, being respectful of differing viewpoints, accepting constructive criticism gracefully, and focusing on what is best for the community.

**Unacceptable behavior includes:** trolling, personal or political attacks, public or private harassment, and other conduct which could reasonably be considered inappropriate in a professional setting.

## Enforcement

Instances of unacceptable behavior may be reported by opening an issue or contacting the maintainers. All complaints will be reviewed and investigated promptly and fairly.

## Attribution

This Code of Conduct is adapted from the [Contributor Covenant](https://www.contributor-covenant.org), version 3.0.
